@@ -1,6 +1,8 @@
 """Create logistic estimators based on the sparse group lasso."""
+import contextlib
 import logging
 import numpy as np
+import warnings
 
 from joblib import delayed, effective_n_jobs, Parallel
 from scipy import sparse
@@ -752,6 +754,11 @@ class LogisticSGLCV(LogisticSGL):
         If None, the random number generator is the RandomState instance used
         by `np.random`.
 
+    suppress_solver_warnings : bool, default=True
+        If True, suppress warnings from BayesSearchCV when the objective is
+        evaluated at the same point multiple times. Setting this to False,
+        may be useful for debugging.
+
     Attributes
     ----------
     alpha_ : float
@@ -814,6 +821,7 @@ class LogisticSGLCV(LogisticSGL):
         n_bayes_iter=50,
         n_bayes_points=1,
         random_state=None,
+        suppress_solver_warnings=True,
     ):
         self.l1_ratio = l1_ratio
         self.groups = groups
@@ -834,6 +842,7 @@ class LogisticSGLCV(LogisticSGL):
         self.n_bayes_iter = n_bayes_iter
         self.n_bayes_points = n_bayes_points
         self.random_state = random_state
+        self.suppress_solver_warnings = suppress_solver_warnings
 
     def fit(self, X, y):
         """Fit logistic sparse group lasso linear model.
@@ -1107,7 +1116,20 @@ class LogisticSGLCV(LogisticSGL):
                 error_score=-np.inf,
             )
 
-            self.bayes_optimizer_.fit(X, y)
+            if self.suppress_solver_warnings:
+                ctx_mgr = warnings.catch_warnings()
+            else:
+                ctx_mgr = contextlib.suppress()
+
+            with ctx_mgr:
+                # If n_bayes_points > 1 the objective may be evaluated at the
+                # same point multiple times. This is okay and we give the user
+                # the choice as to whether or not to see these warnings. The
+                # default is to suppress them.
+                if self.suppress_solver_warnings:
+                    warnings.filterwarnings("ignore", category=UserWarning)
+
+                self.bayes_optimizer_.fit(X, y)
 
             self.alpha_ = self.bayes_optimizer_.best_estimator_.alpha
             self.l1_ratio_ = self.bayes_optimizer_.best_estimator_.l1_ratio
